@@ -1,5 +1,40 @@
 """
 Translation support for admin forms.
+
+*django-parler* provides the following classes:
+
+* Model support: :class:`TranslatableAdmin`.
+* Inline support: :class:`TranslatableInlineModelAdmin`, :class:`TranslatableStackedInline`, :class:`TranslatableTabularInline`.
+* Utilities: :class:`SortedRelatedFieldListFilter`.
+
+Admin classes can be created as expected:
+
+.. code-block:: python
+
+    from django.contrib import admin
+    from parler.admin import TranslatableAdmin
+    from myapp.models import Project
+
+    class ProjectAdmin(TranslatableAdmin):
+        list_display = ('title', 'status')
+        fieldsets = (
+            (None, {
+                'fields': ('title', 'status'),
+            }),
+        )
+
+    admin.site.register(Project, ProjectAdmin)
+
+All translated fields can be used in the :attr:`~django.contrib.admin.ModelAdmin.list_display`
+and :attr:`~django.contrib.admin.ModelAdmin.fieldsets` like normal fields.
+
+While almost every admin feature just works, there are a few special cases to take care of:
+
+* The :attr:`~django.contrib.admin.ModelAdmin.search_fields` needs the actual ORM fields.
+* The :attr:`~django.contrib.admin.ModelAdmin.prepopulated_fields` needs to be replaced with a call
+  to :func:`~django.contrib.admin.ModelAdmin.get_prepopulated_fields`.
+
+See the :ref:`admin compatibility page <admin-compat>` for details.
 """
 from __future__ import unicode_literals
 import django
@@ -30,6 +65,14 @@ from parler.utils.template import select_template_name
 # Code partially taken from django-hvad
 # which is (c) 2011, Jonas Obrist, BSD licensed
 
+__all__ = (
+    'BaseTranslatableAdmin',
+    'TranslatableAdmin',
+    'TranslatableInlineModelAdmin',
+    'TranslatableStackedInline',
+    'TranslatableTabularInline',
+    'SortedRelatedFieldListFilter',
+)
 
 _language_media = Media(css={
     'all': ('parler/admin/language_tabs.css',)
@@ -101,11 +144,14 @@ class BaseTranslatableAdmin(BaseModelAdmin):
             return get_language()
 
 
-    def queryset(self, request):
+    def get_queryset(self, request):
         """
         Make sure the current language is selected.
         """
-        qs = super(BaseTranslatableAdmin, self).queryset(request)
+        if django.VERSION >= (1, 6):
+            qs = super(BaseTranslatableAdmin, self).get_queryset(request)
+        else:
+            qs = super(BaseTranslatableAdmin, self).queryset(request)
 
         if self._has_translatable_model():
             if not isinstance(qs, TranslatableQuerySet):
@@ -118,6 +164,8 @@ class BaseTranslatableAdmin(BaseModelAdmin):
 
         return qs
 
+    # For Django 1.5
+    queryset = get_queryset
 
     def get_language_tabs(self, request, obj, available_languages, css_class=None):
         """
@@ -217,7 +265,8 @@ class TranslatableAdmin(BaseTranslatableAdmin, admin.ModelAdmin):
         if not self._has_translatable_model():
             return urlpatterns
         else:
-            info = self.model._meta.app_label, self.model._meta.module_name
+            opts = self.model._meta
+            info = opts.app_label, opts.model_name if django.VERSION >= (1, 7) else opts.module_name
 
             return patterns('',
                 url(r'^(.+)/delete-translation/(.+)/$',
@@ -278,7 +327,8 @@ class TranslatableAdmin(BaseTranslatableAdmin, admin.ModelAdmin):
             return redirect  # a 200 response likely.
 
         uri = iri_to_uri(request.path)
-        info = (self.model._meta.app_label, self.model._meta.module_name)
+        opts = self.model._meta
+        info = (opts.app_label, opts.model_name if django.VERSION >= (1, 7) else opts.module_name)
 
         # Pass ?language=.. to next page.
         language = request.GET.get(self.query_language_key)
@@ -339,7 +389,7 @@ class TranslatableAdmin(BaseTranslatableAdmin, admin.ModelAdmin):
             ))
 
             if self.has_change_permission(request, None):
-                return HttpResponseRedirect(reverse('admin:{0}_{1}_changelist'.format(opts.app_label, opts.module_name)))
+                return HttpResponseRedirect(reverse('admin:{0}_{1}_changelist'.format(opts.app_label, opts.model_name if django.VERSION >= (1, 7) else opts.module_name)))
             else:
                 return HttpResponseRedirect(reverse('admin:index'))
 
@@ -538,3 +588,26 @@ class TranslatableTabularInline(TranslatableInlineModelAdmin):
         else:
             # Admin default
             return 'admin/edit_inline/tabular.html'
+
+
+class SortedRelatedFieldListFilter(admin.RelatedFieldListFilter):
+    """
+    Override the standard :class:`~django.contrib.admin.RelatedFieldListFilter`,
+    to sort the values after rendering their ``__unicode__()`` values.
+    This can be used for translated models, which are difficult to sort beforehand.
+    Usage:
+
+    .. code-block:: python
+
+        from django.contrib import admin
+        from parler.admin import SortedRelatedFieldListFilter
+
+        class MyAdmin(admin.ModelAdmin):
+
+            list_filter = (
+                ('related_field_name', SortedRelatedFieldListFilter),
+            )
+    """
+    def __init__(self, *args, **kwargs):
+        super(SortedRelatedFieldListFilter, self).__init__(*args, **kwargs)
+        self.lookup_choices = sorted(self.lookup_choices, key=lambda a: a[1].lower())
