@@ -1,7 +1,17 @@
 """
-Model fields
+All fields that are attached to the models.
+
+The core design of django-parler is to attach descriptor fields
+to the shared model, which then proxies the get/set calls to the translated model.
+
+The :class:`TranslatedField` objects are automatically added to the shared model,
+but may be added explicitly as well. This also allows to set the ``any_language`` configuration option.
+It's also useful for abstract models; add a :class:`TranslatedField` to
+indicate that the derived model is expected to provide that translatable field.
 """
+from __future__ import unicode_literals
 from django.db.models.fields import Field
+from django.forms.forms import pretty_name
 
 
 # TODO: inherit RelatedField?
@@ -15,16 +25,20 @@ class TranslatedField(object):
     even when the current language and fallback are missing.
     This can be useful for "title" attributes for example.
 
-    Example::
+    Example:
+
+    .. code-block:: python
+
         from django.db import models
         from parler.models import TranslatableModel, TranslatedFieldsModel
 
         class MyModel(TranslatableModel):
-            title = TranslatedField(any_language=True)
-            slug = TranslatedField()   # Optional, but explicitly mentioned
+            title = TranslatedField(any_language=True)  # Add with any-fallback support
+            slug = TranslatedField()                    # Optional, but explicitly mentioned
+
 
-        # Manual model class
         class MyModelTranslation(TranslatedFieldsModel):
+            # Manual model class:
             master = models.ForeignKey(MyModel, related_name='translations', null=True)
             title = models.CharField("Title", max_length=200)
             slug = models.SlugField("Slug")
@@ -50,6 +64,9 @@ class TranslatedFieldDescriptor(object):
     This attribute proxies all get/set calls to the translated model.
     """
     def __init__(self, field):
+        """
+        :type field: TranslatedField
+        """
         self.field = field
 
     def __get__(self, instance, instance_type=None):
@@ -92,6 +109,27 @@ class TranslatedFieldDescriptor(object):
     def __repr__(self):
         return "<{0} for {1}.{2}>".format(self.__class__.__name__, self.field.model.__name__, self.field.name)
 
+    @property
+    def short_description(self):
+        """
+        Ensure that the admin ``list_display`` renders the correct verbose name for translated fields.
+
+        The :func:`~django.contrib.admin.util.label_for_field` function
+        uses :func:`~django.db.models.Options.get_field_by_name` to find the find and ``verbose_name``.
+        However, for translated fields, this option does not exist,
+        hence it falls back to reading the attribute and trying ``short_description``.
+        Ideally, translated fields should also appear in this list, to be treated like regular fields.
+        """
+        model = self.field.model
+        translations_model = model._translations_model
+        if translations_model is None:
+            # This only happens with abstract models. The code is accessing the descriptor at the base model directly,
+            # not the upgraded descriptor version that contribute_translations() installed.
+            # Fallback to what the admin label_for_field() would have done otherwise.
+            return pretty_name(self.field.name)
+
+        return translations_model._meta.get_field_by_name(self.field.name)[0].verbose_name
+
 
 class LanguageCodeDescriptor(object):
     """
