@@ -1,7 +1,6 @@
-from django.conf import settings
+from __future__ import unicode_literals
 from django.utils import translation
 from parler.models import TranslationDoesNotExist
-from parler import appsettings
 from .utils import AppTestCase
 from .testapp.models import SimpleModel, AnyLanguageModel, EmptyModel
 
@@ -10,14 +9,6 @@ class ModelAttributeTests(AppTestCase):
     """
     Test model construction
     """
-    @classmethod
-    def setUpClass(cls):
-        # Be supportive for other project settings too.
-        cls.conf_fallback = appsettings.PARLER_LANGUAGES['default']['fallback'] or 'en'
-        cls.other_lang1 = next(x for x, _ in settings.LANGUAGES if x != cls.conf_fallback)
-        cls.other_lang2 = next(x for x, _ in settings.LANGUAGES if x not in (cls.conf_fallback, cls.other_lang1))
-
-
     def test_untranslated_get(self):
         """
         Test the metaclass of the model.
@@ -87,8 +78,8 @@ class ModelAttributeTests(AppTestCase):
         x.save()
 
         # Check if all translations are saved.
-        self.assertEqual(sorted(x.translations.values_list('tr_title', flat=True)), [u'TITLE_EN', u'TITLE_ES', u'TITLE_FR', u'TITLE_NL'])
-        self.assertEqual(sorted(x.get_available_languages()), [u'en', u'es', u'fr', u'nl'])
+        self.assertEqual(sorted(x.translations.values_list('tr_title', flat=True)), ['TITLE_EN', 'TITLE_ES', 'TITLE_FR', 'TITLE_NL'])
+        self.assertEqual(sorted(x.get_available_languages()), ['en', 'es', 'fr', 'nl'])
         self.assertTrue(x.has_translation('en'))
         self.assertTrue(x.has_translation('es'))
         self.assertFalse(x.has_translation('fi'))
@@ -106,7 +97,7 @@ class ModelAttributeTests(AppTestCase):
         x.set_current_language('it', initialize=True)
         self.assertTrue(x.has_translation('it'))  # does return true for this object.
         self.assertNumQueries(0, x.save_translations())
-        self.assertEqual(sorted(x.get_available_languages()), [u'en', u'es', u'fr', u'nl'])
+        self.assertEqual(sorted(x.get_available_languages()), ['en', 'es', 'fr', 'nl'])
 
 
     def test_empty_model(self):
@@ -120,7 +111,7 @@ class ModelAttributeTests(AppTestCase):
         x.set_current_language('nl', initialize=True)
         x.save()
 
-        self.assertEqual(sorted(x.get_available_languages()), [u'en', u'fr', u'nl'])
+        self.assertEqual(sorted(x.get_available_languages()), ['en', 'fr', 'nl'])
 
 
     def test_fallback_language(self):
